From: "Gustavo L. de M. Chaves" <gnust...@cpan.org>

Windows specific code was mentioning ActiveState Perl specifically,
but that code works with Strawberry Perl too.

Hence, we rename every instance of 'ActivePerl' to 'Windows' to convey
the more general idea.

Signed-off-by: Gustavo L. de M. Chaves <gnust...@cpan.org>
---
 perl/Git.pm | 17 ++++++++---------
 1 file changed, 8 insertions(+), 9 deletions(-)

diff --git a/perl/Git.pm b/perl/Git.pm
index fdef024..e03b82f 100644
--- a/perl/Git.pm
+++ b/perl/Git.pm
@@ -1297,11 +1297,10 @@ sub _command_common_pipe {
 
        my $fh;
        if ($^O eq 'MSWin32') {
-               # ActiveState Perl
                #defined $opts{STDERR} and
-               #       warn 'ignoring STDERR option - running w/ ActiveState';
+               #       warn 'ignoring STDERR option - running on Windows;
                $direction eq '-|' or
-                       die 'input pipe for ActiveState not implemented';
+                       die 'input pipe for Windows not implemented';
 
                # Set up repo environment
                local $ENV{GIT_DIR}       = $self->repo_path() if defined $self 
&& $self->repo_path();
@@ -1315,13 +1314,13 @@ sub _command_common_pipe {
                        chdir $self->wc_subdir() if $self->wc_subdir();
                }
 
                # the strange construction with *ACPIPE is just to
                # explain the tie below that we want to bind to
                # a handle class, not scalar. It is not known if
                # it is something specific to ActiveState Perl or
                # just a Perl quirk.
-               tie (*ACPIPE, 'Git::activestate_pipe', $cmd, @args);
-               $fh = *ACPIPE;
+               tie (*WINPIPE, 'Git::windows_pipe', $cmd, @args);
+               $fh = *WINPIPE;
 
                chdir $cwd;
        } else {
@@ -1391,9 +1390,9 @@ sub DESTROY {
 }
 
 
 # Pipe implementation for ActiveState Perl.
 
-package Git::activestate_pipe;
+package Git::windows_pipe;
 use strict;
 
 sub TIEHANDLE {
@@ -1315,13 +1314,13 @@ sub _command_common_pipe {
                }
 
-               # the strange construction with *ACPIPE is just to
+               # the strange construction with *WINPIPE is just to
                # explain the tie below that we want to bind to
                # a handle class, not scalar. It is not known if
@@ -1315,13 +1314,13 @@ sub _command_common_pipe {
                # explain the tie below that we want to bind to
                # a handle class, not scalar. It is not known if
-               # it is something specific to ActiveState Perl or
+               # it is something specific to Perl on Windows or
                # just a Perl quirk.
@@ -1391,9 +1390,9 @@ sub DESTROY {
 
 
-# Pipe implementation for ActiveState Perl.
+# Pipe implementation for Perl on Windows.
 
-- 
1.7.12.464.g83379df.dirty

--
To unsubscribe from this list: send the line "unsubscribe git" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to